Philox Counter-based RNG
------------------------

.. currentmodule:: numpy.random

.. autoclass:: Philox
    :members: __init__
    :exclude-members: __init__

State
=====

.. autosummary::
   :toctree: generated/

   ~Philox.state

Parallel generation
===================
.. autosummary::
   :toctree: generated/

   ~Philox.advance
   ~Philox.jumped

Extending
=========
.. autosummary::
   :toctree: generated/

   ~Philox.cffi
   ~Philox.ctypes


